@@ -3,8 +3,10 @@ use Bricklayer::Templater::Handler;
 use base qw(Bricklayer::Templater::Handler);
 
 sub run {
-	my $select = $_[0]->{Token}{attributes}{key};
-	my $contents = $_[0]->{App}->run_sequencer($_[0]->{Token}{block}, undef, $_[1]) unless $_[1]->{$select};
+    my $self = shift;
+    my $arg  = shift;
+	my $select = $self->attributes()->{key};
+	my $contents = $self()->app()->run_sequencer($self->block(), $arg) unless $arg->{$select};
 	return;
 }
 
